From 26ea6b954636b334e4f31da97c30e215aa83f4a1 Mon Sep 17 00:00:00 2001
From: Lioncash <mathew1800@gmail.com>
Date: Wed, 7 Dec 2016 17:42:51 -0500
Subject: [PATCH] Update AM service function tables

Updated based off information from 3dbrew.
---
 src/core/hle/service/am/am.cpp     |  10 +-
 src/core/hle/service/am/am.h       |  20 ++--
 src/core/hle/service/am/am_app.cpp |   5 +
 src/core/hle/service/am/am_net.cpp | 157 +++++++++++++++++++----------
 src/core/hle/service/am/am_sys.cpp |  71 +++++++++----
 src/core/hle/service/am/am_u.cpp   |  96 ++++++++++++------
 6 files changed, 246 insertions(+), 113 deletions(-)

diff --git a/src/core/hle/service/am/am.cpp b/src/core/hle/service/am/am.cpp
index f7a990d69..d344a622f 100644
--- a/src/core/hle/service/am/am.cpp
+++ b/src/core/hle/service/am/am.cpp
@@ -20,7 +20,7 @@ static std::array<u32, 3> am_titles_list_count = {0, 0, 0};
 static u32 am_ticket_count = 0;
 static u32 am_ticket_list_count = 0;
 
-void GetTitleCount(Service::Interface* self) {
+void GetNumPrograms(Service::Interface* self) {
     u32* cmd_buff = Kernel::GetCommandBuffer();
 
     u32 media_type = cmd_buff[1] & 0xFF;
@@ -81,7 +81,7 @@ void DeleteContents(Service::Interface* self) {
                 media_type, title_id, am_content_count[media_type], content_ids_pointer);
 }
 
-void GetTitleList(Service::Interface* self) {
+void GetProgramList(Service::Interface* self) {
     u32* cmd_buff = Kernel::GetCommandBuffer();
 
     u32 media_type = cmd_buff[2] & 0xFF;
@@ -97,7 +97,7 @@ void GetTitleList(Service::Interface* self) {
         media_type, am_titles_list_count[media_type], title_ids_output_pointer);
 }
 
-void GetTitleInfo(Service::Interface* self) {
+void GetProgramInfos(Service::Interface* self) {
     u32* cmd_buff = Kernel::GetCommandBuffer();
 
     u32 media_type = cmd_buff[1] & 0xFF;
@@ -113,7 +113,7 @@ void GetTitleInfo(Service::Interface* self) {
 }
 
 void GetDataTitleInfos(Service::Interface* self) {
-    GetTitleInfo(self);
+    GetProgramInfos(self);
 
     LOG_WARNING(Service_AM, "(STUBBED) called");
 }
@@ -151,7 +151,7 @@ void DeleteTicket(Service::Interface* self) {
     LOG_WARNING(Service_AM, "(STUBBED) called title_id=0x%016" PRIx64 "", title_id);
 }
 
-void GetTicketCount(Service::Interface* self) {
+void GetNumTickets(Service::Interface* self) {
     u32* cmd_buff = Kernel::GetCommandBuffer();
 
     cmd_buff[1] = RESULT_SUCCESS.raw;
diff --git a/src/core/hle/service/am/am_app.cpp b/src/core/hle/service/am/am_app.cpp
index bfc1ca6bd..218375c8f 100644
--- a/src/core/hle/service/am/am_app.cpp
+++ b/src/core/hle/service/am/am_app.cpp
@@ -14,9 +14,14 @@ const Interface::FunctionInfo FunctionTable[] = {
     {0x10030142, ListContentInfos, "ListContentInfos"},
     {0x10040102, DeleteContents, "DeleteContents"},
     {0x10050084, GetDataTitleInfos, "GetDataTitleInfos"},
+    {0x10060080, nullptr, "GetNumDataTitleTickets"},
     {0x10070102, ListDataTitleTicketInfos, "ListDataTitleTicketInfos"},
+    {0x100801C2, nullptr, "GetItemRights"},
     {0x100900C0, nullptr, "IsDataTitleInUse"},
     {0x100A0000, nullptr, "IsExternalTitleDatabaseInitialized"},
+    {0x100B00C0, nullptr, "GetNumExistingContentInfos"},
+    {0x100C0142, nullptr, "ListExistingContentInfos"},
+    {0x100D0084, nullptr, "GetPatchTitleInfos"},
 };
 
 AM_APP_Interface::AM_APP_Interface() {
diff --git a/src/core/hle/service/am/am_net.cpp b/src/core/hle/service/am/am_net.cpp
index 3a597a34c..f3cd1d23f 100644
--- a/src/core/hle/service/am/am_net.cpp
+++ b/src/core/hle/service/am/am_net.cpp
@@ -9,61 +9,116 @@ namespace Service {
 namespace AM {
 
 const Interface::FunctionInfo FunctionTable[] = {
-    {0x00010040, GetTitleCount, "GetTitleCount"},
-    {0x00020082, GetTitleList, "GetTitleList"},
-    {0x00030084, GetTitleInfo, "GetTitleInfo"},
-    {0x000400C0, nullptr, "DeleteApplicationTitle"},
-    {0x000500C0, nullptr, "GetTitleProductCode"},
-    {0x000600C0, nullptr, "GetTitleExtDataId"},
+    {0x00010040, GetNumPrograms, "GetNumPrograms"},
+    {0x00020082, GetProgramList, "GetProgramList"},
+    {0x00030084, GetProgramInfos, "GetProgramInfos"},
+    {0x000400C0, nullptr, "DeleteUserProgram"},
+    {0x000500C0, nullptr, "GetProductCode"},
+    {0x000600C0, nullptr, "GetStorageId"},
     {0x00070080, DeleteTicket, "DeleteTicket"},
-    {0x00080000, GetTicketCount, "GetTicketCount"},
+    {0x00080000, GetNumTickets, "GetNumTickets"},
     {0x00090082, GetTicketList, "GetTicketList"},
     {0x000A0000, nullptr, "GetDeviceID"},
-    {0x000D0084, nullptr, "GetPendingTitleInfo"},
-    {0x000E00C0, nullptr, "DeletePendingTitle"},
-    {0x00140040, nullptr, "FinalizePendingTitles"},
-    {0x00150040, nullptr, "DeleteAllPendingTitles"},
+    {0x000B0040, nullptr, "GetNumImportTitleContexts"},
+    {0x000C0082, nullptr, "GetImportTitleContextList"},
+    {0x000D0084, nullptr, "GetImportTitleContexts"},
+    {0x000E00C0, nullptr, "DeleteImportTitleContext"},
+    {0x000F00C0, nullptr, "GetNumImportContentContexts"},
+    {0x00100102, nullptr, "GetImportContentContextList"},
+    {0x00110104, nullptr, "GetImportContentContexts"},
+    {0x00120102, nullptr, "DeleteImportContentContexts"},
+    {0x00130040, nullptr, "NeedsCleanup"},
+    {0x00140040, nullptr, "DoCleanup"},
+    {0x00150040, nullptr, "DeleteAllImportContexts"},
+    {0x00160000, nullptr, "DeleteAllTemporaryPrograms"},
+    {0x00170044, nullptr, "ImportTwlBackupLegacy"},
     {0x00180080, nullptr, "InitializeTitleDatabase"},
-    {0x00190040, nullptr, "ReloadDBS"},
-    {0x001A00C0, nullptr, "GetDSiWareExportSize"},
-    {0x001B0144, nullptr, "ExportDSiWare"},
-    {0x001C0084, nullptr, "ImportDSiWare"},
-    {0x00230080, nullptr, "TitleIDListGetTotal2"},
-    {0x002400C2, nullptr, "GetTitleIDList2"},
-    {0x04010080, nullptr, "InstallFIRM"},
-    {0x04020040, nullptr, "StartInstallCIADB0"},
-    {0x04030000, nullptr, "StartInstallCIADB1"},
-    {0x04040002, nullptr, "AbortCIAInstall"},
-    {0x04050002, nullptr, "CloseCIAFinalizeInstall"},
-    {0x04060002, nullptr, "CloseCIA"},
-    {0x040700C2, nullptr, "FinalizeTitlesInstall"},
-    {0x04080042, nullptr, "GetCiaFileInfo"},
-    {0x040E00C2, nullptr, "InstallTitlesFinish"},
-    {0x040F0000, nullptr, "InstallNATIVEFIRM"},
-    {0x041000C0, nullptr, "DeleteTitle"},
-    {0x04120000, nullptr, "Initialize"},
-    {0x041700C0, nullptr, "MigrateAGBtoSAV"},
-    {0x08010000, nullptr, "OpenTicket"},
-    {0x08020002, nullptr, "TicketAbortInstall"},
-    {0x08030002, nullptr, "TicketFinalizeInstall"},
-    {0x08040100, nullptr, "InstallTitleBegin"},
-    {0x08050000, nullptr, "InstallTitleAbort"},
-    {0x080600C0, nullptr, "InstallTitleResume"},
-    {0x08070000, nullptr, "InstallTitleAbortTMD"},
-    {0x08080000, nullptr, "InstallTitleFinish"},
-    {0x080A0000, nullptr, "OpenTMD"},
-    {0x080B0002, nullptr, "TMDAbortInstall"},
-    {0x080C0042, nullptr, "TMDFinalizeInstall"},
-    {0x080E0040, nullptr, "OpenContentCreate"},
-    {0x080F0002, nullptr, "ContentAbortInstall"},
-    {0x08100040, nullptr, "OpenContentResume"},
-    {0x08120002, nullptr, "ContentFinalizeInstall"},
-    {0x08130000, nullptr, "GetTotalContents"},
-    {0x08140042, nullptr, "GetContentIndexes"},
-    {0x08150044, nullptr, "GetContentsInfo"},
-    {0x08180042, nullptr, "GetCTCert"},
-    {0x08190108, nullptr, "SetCertificates"},
-    {0x081B00C2, nullptr, "InstallTitlesFinish"},
+    {0x00190040, nullptr, "QueryAvailableTitleDatabase"},
+    {0x001A00C0, nullptr, "CalcTwlBackupSize"},
+    {0x001B0144, nullptr, "ExportTwlBackup"},
+    {0x001C0084, nullptr, "ImportTwlBackup"},
+    {0x001D0000, nullptr, "DeleteAllTwlUserPrograms"},
+    {0x001E00C8, nullptr, "ReadTwlBackupInfo"},
+    {0x001F0040, nullptr, "DeleteAllExpiredUserPrograms"},
+    {0x00200000, nullptr, "GetTwlArchiveResourceInfo"},
+    {0x00210042, nullptr, "GetPersonalizedTicketInfoList"},
+    {0x00220080, nullptr, "DeleteAllImportContextsFiltered"},
+    {0x00230080, nullptr, "GetNumImportTitleContextsFiltered"},
+    {0x002400C2, nullptr, "GetImportTitleContextListFiltered"},
+    {0x002500C0, nullptr, "CheckContentRights"},
+    {0x00260044, nullptr, "GetTicketLimitInfos"},
+    {0x00270044, nullptr, "GetDemoLaunchInfos"},
+    {0x00280108, nullptr, "ReadTwlBackupInfoEx"},
+    {0x00290082, nullptr, "DeleteUserProgramsAtomically"},
+    {0x002A00C0, nullptr, "GetNumExistingContentInfosSystem"},
+    {0x002B0142, nullptr, "ListExistingContentInfosSystem"},
+    {0x002C0084, nullptr, "GetProgramInfosIgnorePlatform"},
+    {0x002D00C0, nullptr, "CheckContentRightsIgnorePlatform"},
+    {0x04010080, nullptr, "UpdateFirmwareTo"},
+    {0x04020040, nullptr, "BeginImportProgram"},
+    {0x04030000, nullptr, "BeginImportProgramTemporarily"},
+    {0x04040002, nullptr, "CancelImportProgram"},
+    {0x04050002, nullptr, "EndImportProgram"},
+    {0x04060002, nullptr, "EndImportProgramWithoutCommit"},
+    {0x040700C2, nullptr, "CommitImportPrograms"},
+    {0x04080042, nullptr, "GetProgramInfoFromCia"},
+    {0x04090004, nullptr, "GetSystemMenuDataFromCia"},
+    {0x040A0002, nullptr, "GetDependencyListFromCia"},
+    {0x040B0002, nullptr, "GetTransferSizeFromCia"},
+    {0x040C0002, nullptr, "GetCoreVersionFromCia"},
+    {0x040D0042, nullptr, "GetRequiredSizeFromCia"},
+    {0x040E00C2, nullptr, "CommitImportProgramsAndUpdateFirmwareAuto"},
+    {0x040F0000, nullptr, "UpdateFirmwareAuto"},
+    {0x041000C0, nullptr, "DeleteProgram"},
+    {0x04110044, nullptr, "GetTwlProgramListForReboot"},
+    {0x04120000, nullptr, "GetSystemUpdaterMutex"},
+    {0x04130002, nullptr, "GetMetaSizeFromCia"},
+    {0x04140044, nullptr, "GetMetaDataFromCia"},
+    {0x04150080, nullptr, "CheckDemoLaunchRights"},
+    {0x041600C0, nullptr, "GetInternalTitleLocationInfo"},
+    {0x041700C0, nullptr, "PerpetuateAgbSaveData"},
+    {0x04180040, nullptr, "BeginImportProgramForOverWrite"},
+    {0x04190000, nullptr, "BeginImportSystemProgram"},
+    {0x08010000, nullptr, "BeginImportTicket"},
+    {0x08020002, nullptr, "CancelImportTicket"},
+    {0x08030002, nullptr, "EndImportTicket"},
+    {0x08040100, nullptr, "BeginImportTitle"},
+    {0x08050000, nullptr, "StopImportTitle"},
+    {0x080600C0, nullptr, "ResumeImportTitle"},
+    {0x08070000, nullptr, "CancelImportTitle"},
+    {0x08080000, nullptr, "EndImportTitle"},
+    {0x080900C2, nullptr, "CommitImportTitles"},
+    {0x080A0000, nullptr, "BeginImportTmd"},
+    {0x080B0002, nullptr, "CancelImportTmd"},
+    {0x080C0042, nullptr, "EndImportTmd"},
+    {0x080D0042, nullptr, "CreateImportContentContexts"},
+    {0x080E0040, nullptr, "BeginImportContent"},
+    {0x080F0002, nullptr, "StopImportContent"},
+    {0x08100040, nullptr, "ResumeImportContent"},
+    {0x08110002, nullptr, "CancelImportContent"},
+    {0x08120002, nullptr, "EndImportContent"},
+    {0x08130000, nullptr, "GetNumCurrentImportContentContexts"},
+    {0x08140042, nullptr, "GetCurrentImportContentContextList"},
+    {0x08150044, nullptr, "GetCurrentImportContentContexts"},
+    {0x08160146, nullptr, "Sign"},
+    {0x08170146, nullptr, "Verify"},
+    {0x08180042, nullptr, "GetDeviceCert"},
+    {0x08190108, nullptr, "ImportCertificates"},
+    {0x081A0042, nullptr, "ImportCertificate"},
+    {0x081B00C2, nullptr, "CommitImportTitlesAndUpdateFirmwareAuto"},
+    {0x081C0100, nullptr, "DeleteTicketId"},
+    {0x081D0080, nullptr, "GetNumTicketIds"},
+    {0x081E0102, nullptr, "GetTicketIdList"},
+    {0x081F0080, nullptr, "GetNumTicketsOfProgram"},
+    {0x08200102, nullptr, "ListTicketInfos"},
+    {0x08210142, nullptr, "GetRightsOnlyTicketData"},
+    {0x08220000, nullptr, "GetNumCurrentContentInfos"},
+    {0x08230044, nullptr, "FindCurrentContentInfos"},
+    {0x08240082, nullptr, "ListCurrentContentInfos"},
+    {0x08250102, nullptr, "CalculateContextRequiredSize"},
+    {0x08260042, nullptr, "UpdateImportContentContexts"},
+    {0x08270000, nullptr, "DeleteAllDemoLaunchInfos"},
+    {0x082800C0, nullptr, "BeginImportTitleForOverWrite"},
 };
 
 AM_NET_Interface::AM_NET_Interface() {
diff --git a/src/core/hle/service/am/am_sys.cpp b/src/core/hle/service/am/am_sys.cpp
index a2268303c..949b3591d 100644
--- a/src/core/hle/service/am/am_sys.cpp
+++ b/src/core/hle/service/am/am_sys.cpp
@@ -9,27 +9,64 @@ namespace Service {
 namespace AM {
 
 const Interface::FunctionInfo FunctionTable[] = {
-    {0x00010040, GetTitleCount, "GetTitleCount"},
-    {0x00020082, GetTitleList, "GetTitleList"},
-    {0x00030084, GetTitleInfo, "GetTitleInfo"},
-    {0x000400C0, nullptr, "DeleteApplicationTitle"},
-    {0x000500C0, nullptr, "GetTitleProductCode"},
-    {0x000600C0, nullptr, "GetTitleExtDataId"},
+    {0x00010040, GetNumPrograms, "GetNumPrograms"},
+    {0x00020082, GetProgramList, "GetProgramList"},
+    {0x00030084, GetProgramInfos, "GetProgramInfos"},
+    {0x000400C0, nullptr, "DeleteUserProgram"},
+    {0x000500C0, nullptr, "GetProductCode"},
+    {0x000600C0, nullptr, "GetStorageId"},
     {0x00070080, DeleteTicket, "DeleteTicket"},
-    {0x00080000, GetTicketCount, "GetTicketCount"},
+    {0x00080000, GetNumTickets, "GetNumTickets"},
     {0x00090082, GetTicketList, "GetTicketList"},
     {0x000A0000, nullptr, "GetDeviceID"},
-    {0x000D0084, nullptr, "GetPendingTitleInfo"},
-    {0x000E00C0, nullptr, "DeletePendingTitle"},
-    {0x00140040, nullptr, "FinalizePendingTitles"},
-    {0x00150040, nullptr, "DeleteAllPendingTitles"},
+    {0x000B0040, nullptr, "GetNumImportTitleContexts"},
+    {0x000C0082, nullptr, "GetImportTitleContextList"},
+    {0x000D0084, nullptr, "GetImportTitleContexts"},
+    {0x000E00C0, nullptr, "DeleteImportTitleContext"},
+    {0x000F00C0, nullptr, "GetNumImportContentContexts"},
+    {0x00100102, nullptr, "GetImportContentContextList"},
+    {0x00110104, nullptr, "GetImportContentContexts"},
+    {0x00120102, nullptr, "DeleteImportContentContexts"},
+    {0x00130040, nullptr, "NeedsCleanup"},
+    {0x00140040, nullptr, "DoCleanup"},
+    {0x00150040, nullptr, "DeleteAllImportContexts"},
+    {0x00160000, nullptr, "DeleteAllTemporaryPrograms"},
+    {0x00170044, nullptr, "ImportTwlBackupLegacy"},
     {0x00180080, nullptr, "InitializeTitleDatabase"},
-    {0x00190040, nullptr, "ReloadDBS"},
-    {0x001A00C0, nullptr, "GetDSiWareExportSize"},
-    {0x001B0144, nullptr, "ExportDSiWare"},
-    {0x001C0084, nullptr, "ImportDSiWare"},
-    {0x00230080, nullptr, "GetPendingTitleCount"},
-    {0x002400C2, nullptr, "GetPendingTitleList"},
+    {0x00190040, nullptr, "QueryAvailableTitleDatabase"},
+    {0x001A00C0, nullptr, "CalcTwlBackupSize"},
+    {0x001B0144, nullptr, "ExportTwlBackup"},
+    {0x001C0084, nullptr, "ImportTwlBackup"},
+    {0x001D0000, nullptr, "DeleteAllTwlUserPrograms"},
+    {0x001E00C8, nullptr, "ReadTwlBackupInfo"},
+    {0x001F0040, nullptr, "DeleteAllExpiredUserPrograms"},
+    {0x00200000, nullptr, "GetTwlArchiveResourceInfo"},
+    {0x00210042, nullptr, "GetPersonalizedTicketInfoList"},
+    {0x00220080, nullptr, "DeleteAllImportContextsFiltered"},
+    {0x00230080, nullptr, "GetNumImportTitleContextsFiltered"},
+    {0x002400C2, nullptr, "GetImportTitleContextListFiltered"},
+    {0x002500C0, nullptr, "CheckContentRights"},
+    {0x00260044, nullptr, "GetTicketLimitInfos"},
+    {0x00270044, nullptr, "GetDemoLaunchInfos"},
+    {0x00280108, nullptr, "ReadTwlBackupInfoEx"},
+    {0x00290082, nullptr, "DeleteUserProgramsAtomically"},
+    {0x002A00C0, nullptr, "GetNumExistingContentInfosSystem"},
+    {0x002B0142, nullptr, "ListExistingContentInfosSystem"},
+    {0x002C0084, nullptr, "GetProgramInfosIgnorePlatform"},
+    {0x002D00C0, nullptr, "CheckContentRightsIgnorePlatform"},
+    {0x100100C0, GetNumContentInfos, "GetNumContentInfos"},
+    {0x10020104, FindContentInfos, "FindContentInfos"},
+    {0x10030142, ListContentInfos, "ListContentInfos"},
+    {0x10040102, DeleteContents, "DeleteContents"},
+    {0x10050084, GetDataTitleInfos, "GetDataTitleInfos"},
+    {0x10060080, nullptr, "GetNumDataTitleTickets"},
+    {0x10070102, ListDataTitleTicketInfos, "ListDataTitleTicketInfos"},
+    {0x100801C2, nullptr, "GetItemRights"},
+    {0x100900C0, nullptr, "IsDataTitleInUse"},
+    {0x100A0000, nullptr, "IsExternalTitleDatabaseInitialized"},
+    {0x100B00C0, nullptr, "GetNumExistingContentInfos"},
+    {0x100C0142, nullptr, "ListExistingContentInfos"},
+    {0x100D0084, nullptr, "GetPatchTitleInfos"},
 };
 
 AM_SYS_Interface::AM_SYS_Interface() {
diff --git a/src/core/hle/service/am/am_u.cpp b/src/core/hle/service/am/am_u.cpp
index 151b5e42b..354d51610 100644
--- a/src/core/hle/service/am/am_u.cpp
+++ b/src/core/hle/service/am/am_u.cpp
@@ -9,40 +9,76 @@ namespace Service {
 namespace AM {
 
 const Interface::FunctionInfo FunctionTable[] = {
-    {0x00010040, GetTitleCount, "GetTitleCount"},
-    {0x00020082, GetTitleList, "GetTitleList"},
-    {0x00030084, GetTitleInfo, "GetTitleInfo"},
-    {0x000400C0, nullptr, "DeleteApplicationTitle"},
-    {0x000500C0, nullptr, "GetTitleProductCode"},
-    {0x000600C0, nullptr, "GetTitleExtDataId"},
+    {0x00010040, GetNumPrograms, "GetNumPrograms"},
+    {0x00020082, GetProgramList, "GetProgramList"},
+    {0x00030084, GetProgramInfos, "GetProgramInfos"},
+    {0x000400C0, nullptr, "DeleteUserProgram"},
+    {0x000500C0, nullptr, "GetProductCode"},
+    {0x000600C0, nullptr, "GetStorageId"},
     {0x00070080, DeleteTicket, "DeleteTicket"},
-    {0x00080000, GetTicketCount, "GetTicketCount"},
+    {0x00080000, GetNumTickets, "GetNumTickets"},
     {0x00090082, GetTicketList, "GetTicketList"},
     {0x000A0000, nullptr, "GetDeviceID"},
-    {0x000D0084, nullptr, "GetPendingTitleInfo"},
-    {0x000E00C0, nullptr, "DeletePendingTitle"},
-    {0x00140040, nullptr, "FinalizePendingTitles"},
-    {0x00150040, nullptr, "DeleteAllPendingTitles"},
+    {0x000B0040, nullptr, "GetNumImportTitleContexts"},
+    {0x000C0082, nullptr, "GetImportTitleContextList"},
+    {0x000D0084, nullptr, "GetImportTitleContexts"},
+    {0x000E00C0, nullptr, "DeleteImportTitleContext"},
+    {0x000F00C0, nullptr, "GetNumImportContentContexts"},
+    {0x00100102, nullptr, "GetImportContentContextList"},
+    {0x00110104, nullptr, "GetImportContentContexts"},
+    {0x00120102, nullptr, "DeleteImportContentContexts"},
+    {0x00130040, nullptr, "NeedsCleanup"},
+    {0x00140040, nullptr, "DoCleanup"},
+    {0x00150040, nullptr, "DeleteAllImportContexts"},
+    {0x00160000, nullptr, "DeleteAllTemporaryPrograms"},
+    {0x00170044, nullptr, "ImportTwlBackupLegacy"},
     {0x00180080, nullptr, "InitializeTitleDatabase"},
-    {0x00190040, nullptr, "ReloadDBS"},
-    {0x001A00C0, nullptr, "GetDSiWareExportSize"},
-    {0x001B0144, nullptr, "ExportDSiWare"},
-    {0x001C0084, nullptr, "ImportDSiWare"},
-    {0x00230080, nullptr, "TitleIDListGetTotal2"},
-    {0x002400C2, nullptr, "GetTitleIDList2"},
-    {0x04010080, nullptr, "InstallFIRM"},
-    {0x04020040, nullptr, "StartInstallCIADB0"},
-    {0x04030000, nullptr, "StartInstallCIADB1"},
-    {0x04040002, nullptr, "AbortCIAInstall"},
-    {0x04050002, nullptr, "CloseCIAFinalizeInstall"},
-    {0x04060002, nullptr, "CloseCIA"},
-    {0x040700C2, nullptr, "FinalizeTitlesInstall"},
-    {0x04080042, nullptr, "GetCiaFileInfo"},
-    {0x040E00C2, nullptr, "InstallTitlesFinish"},
-    {0x040F0000, nullptr, "InstallNATIVEFIRM"},
-    {0x041000C0, nullptr, "DeleteTitle"},
-    {0x04120000, nullptr, "Initialize"},
-    {0x041700C0, nullptr, "MigrateAGBtoSAV"},
+    {0x00190040, nullptr, "QueryAvailableTitleDatabase"},
+    {0x001A00C0, nullptr, "CalcTwlBackupSize"},
+    {0x001B0144, nullptr, "ExportTwlBackup"},
+    {0x001C0084, nullptr, "ImportTwlBackup"},
+    {0x001D0000, nullptr, "DeleteAllTwlUserPrograms"},
+    {0x001E00C8, nullptr, "ReadTwlBackupInfo"},
+    {0x001F0040, nullptr, "DeleteAllExpiredUserPrograms"},
+    {0x00200000, nullptr, "GetTwlArchiveResourceInfo"},
+    {0x00210042, nullptr, "GetPersonalizedTicketInfoList"},
+    {0x00220080, nullptr, "DeleteAllImportContextsFiltered"},
+    {0x00230080, nullptr, "GetNumImportTitleContextsFiltered"},
+    {0x002400C2, nullptr, "GetImportTitleContextListFiltered"},
+    {0x002500C0, nullptr, "CheckContentRights"},
+    {0x00260044, nullptr, "GetTicketLimitInfos"},
+    {0x00270044, nullptr, "GetDemoLaunchInfos"},
+    {0x00280108, nullptr, "ReadTwlBackupInfoEx"},
+    {0x00290082, nullptr, "DeleteUserProgramsAtomically"},
+    {0x002A00C0, nullptr, "GetNumExistingContentInfosSystem"},
+    {0x002B0142, nullptr, "ListExistingContentInfosSystem"},
+    {0x002C0084, nullptr, "GetProgramInfosIgnorePlatform"},
+    {0x002D00C0, nullptr, "CheckContentRightsIgnorePlatform"},
+    {0x04010080, nullptr, "UpdateFirmwareTo"},
+    {0x04020040, nullptr, "BeginImportProgram"},
+    {0x04030000, nullptr, "BeginImportProgramTemporarily"},
+    {0x04040002, nullptr, "CancelImportProgram"},
+    {0x04050002, nullptr, "EndImportProgram"},
+    {0x04060002, nullptr, "EndImportProgramWithoutCommit"},
+    {0x040700C2, nullptr, "CommitImportPrograms"},
+    {0x04080042, nullptr, "GetProgramInfoFromCia"},
+    {0x04090004, nullptr, "GetSystemMenuDataFromCia"},
+    {0x040A0002, nullptr, "GetDependencyListFromCia"},
+    {0x040B0002, nullptr, "GetTransferSizeFromCia"},
+    {0x040C0002, nullptr, "GetCoreVersionFromCia"},
+    {0x040D0042, nullptr, "GetRequiredSizeFromCia"},
+    {0x040E00C2, nullptr, "CommitImportProgramsAndUpdateFirmwareAuto"},
+    {0x040F0000, nullptr, "UpdateFirmwareAuto"},
+    {0x041000C0, nullptr, "DeleteProgram"},
+    {0x04110044, nullptr, "GetTwlProgramListForReboot"},
+    {0x04120000, nullptr, "GetSystemUpdaterMutex"},
+    {0x04130002, nullptr, "GetMetaSizeFromCia"},
+    {0x04140044, nullptr, "GetMetaDataFromCia"},
+    {0x04150080, nullptr, "CheckDemoLaunchRights"},
+    {0x041600C0, nullptr, "GetInternalTitleLocationInfo"},
+    {0x041700C0, nullptr, "PerpetuateAgbSaveData"},
+    {0x04180040, nullptr, "BeginImportProgramForOverWrite"},
+    {0x04190000, nullptr, "BeginImportSystemProgram"},
 };
 
 AM_U_Interface::AM_U_Interface() {
diff --git a/src/core/hle/service/am/am.h b/src/core/hle/service/am/am.h
index 5676cdd5f..9bc2ca305 100644
--- a/src/core/hle/service/am/am.h
+++ b/src/core/hle/service/am/am.h
@@ -11,7 +11,7 @@ class Interface;
 namespace AM {
 
 /**
- * AM::GetTitleCount service function
+ * AM::GetNumPrograms service function
  * Gets the number of installed titles in the requested media type
  *  Inputs:
  *      0 : Command header (0x00010040)
@@ -20,7 +20,7 @@ namespace AM {
  *      1 : Result, 0 on success, otherwise error code
  *      2 : The number of titles in the requested media type
  */
-void GetTitleCount(Service::Interface* self);
+void GetNumPrograms(Service::Interface* self);
 
 /**
  * AM::FindContentInfos service function
@@ -62,7 +62,7 @@ void ListContentInfos(Service::Interface* self);
 void DeleteContents(Service::Interface* self);
 
 /**
  * AM::GetTitleList service function
  * Loads information about the desired number of titles from the desired media type into an array
  *  Inputs:
  *      1 : Title count
@@ -72,10 +72,10 @@ void DeleteContents(Service::Interface* self);
  *      1 : Result, 0 on success, otherwise error code
  *      2 : The number of titles loaded from the requested media type
  */
-void GetTitleList(Service::Interface* self);
+void GetProgramList(Service::Interface* self);
 
 /**
- * AM::GetTitleInfo service function
+ * AM::GetProgramInfos service function
  *  Inputs:
  *      1 : u8 Mediatype
  *      2 : Total titles
@@ -84,11 +84,11 @@ void GetTitleList(Service::Interface* self);
  *  Outputs:
  *      1 : Result, 0 on success, otherwise error code
  */
-void GetTitleInfo(Service::Interface* self);
+void GetProgramInfos(Service::Interface* self);
 
 /**
  * AM::GetDataTitleInfos service function
- * Wrapper for AM::GetTitleInfo
+ * Wrapper for AM::GetProgramInfos
  *  Inputs:
  *      1 : u8 Mediatype
  *      2 : Total titles
@@ -135,12 +135,12 @@ void GetNumContentInfos(Service::Interface* self);
 void DeleteTicket(Service::Interface* self);
 
 /**
- * AM::GetTicketCount service function
+ * AM::GetNumTickets service function
  *  Outputs:
  *      1 : Result, 0 on success, otherwise error code
- *      2 : Total titles
+ *      2 : Number of tickets
  */
-void GetTicketCount(Service::Interface* self);
+void GetNumTickets(Service::Interface* self);
 
 /**
  * AM::GetTicketList service function
@@ -62,7 +62,7 @@ void ListContentInfos(Service::Interface* self);
 
 /**
- * AM::GetTitleList service function
+ * AM::GetProgramList service function
  * Loads information about the desired number of titles from the desired media type into an array
  *  Inputs: